pygeodesy.trf.RefFrame

Package pygeodesy :: Module trf :: Class RefFrame |
[frames] | no frames]

# Class RefFrame

      object --+
               |
    named._Named --+
                   |
    named._NamedBase --+
                       |
    named._NamedEnumItem --+
                           |
                          RefFrame

Terrestrial Reference Frame (TRF) parameters.

Instance Methods
__init__(self, epoch, datum=Datum(name='GRS80', ellipsoid=Ellipsoids.GRS80, transform=Tran`...`, name='') New RefFrame. |
__eq__(self, other) |
__lt__(self, other) |
__matmul__(self, point) DEPRECATED on 2024.02.16, use method `point.toRefFrame`. |
toRefFrame(self, point, reframe2, **epoch_epoch2_name) Convert an ellipsoidal point from this reframe and from `epoch` to an other `reframe2` and `epoch2 or epoch`. |
toStr(self, epoch=None, name='', **unused) Return this reference frame as a string. |
Xform(self, reframe2) Get the converter Xform from this reference frame to `reframe2`. |
Xforms(self, inverse=False) Return all Xforms converting from or to this reference frame or both. |
Inherited from `named._NamedEnumItem`: `unregister` Inherited from `named._NamedBase`: `__repr__`, `__str__`, `others`, `toRepr` Inherited from `named._Named`: `__format__`, `__imatmul__`, `__rmatmul__`, `attrs`, `classof`, `copy`, `dup`, `methodname`, `rename`, `renamed`, `toStr2` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Properties
| datum Get this reference frame's datum (Datum).
| ellipsoid Get this reference frame's ellipsoid (Ellipsoid or Ellipsoid2).
| epoch Get this reference frame's epoch (`Epoch`).
Inherited from `named._NamedEnumItem`: `name` Inherited from `named._Named`: `classname`, `classnaming`, `iteration`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`

Method Details

### __init__ (self, epoch, datum=Datum(name='GRS80', ellipsoid=Ellipsoids.GRS80, transform=Tran`...`, name='') (Constructor) |
New RefFrame. Arguments: `epoch` - Epoch, a fractional calendar year (`scalar` or `str`). `datum` - Datum or ellipsoid (Datum, {Ellipsoid}, Ellipsoid2 or a_f2Tuple). `name` - Unique, non-empty name (`str`). Raises: `NameError` - A RefFrame with that `name` already exists. `TRFError` - Invalid `epoch`. `TypeError` - Invalid `datum`. Overrides: object.__init__

### __matmul__ (self, point) |
DEPRECATED on 2024.02.16, use method `point.toRefFrame`. Decorators: `@deprecated_method` Overrides: named._Named.__matmul__

### toRefFrame (self, point, reframe2, **epoch_epoch2_name) |
Convert an ellipsoidal point from this reframe and from `epoch` to an other `reframe2` and `epoch2 or epoch`. Arguments: `point` - The point to convert (`LatLon` or `Cartesian`). `reframe2` - Reference frame to convert to (RefFrame). `epoch_epoch2_name` - Optional keyword arguments `epoch=None`, `epoch2=None` and `name=reframe2.name`. Returns: A copy of the `point`, converted and renamed. Raises: `TypeError` - Invalid `point`. Note: The `point.reframe` is overridden by this reframe and `point.epoch` by `epoch` or this reframe.`epoch`. See Also: Methods LatLon.toRefFrame and Cartesian.toRefFrame for more details.

### toStr (self, epoch=None, name='', **unused) |
Return this reference frame as a string. Arguments: `epoch` - Override this reframe's epoch (`scalar` or `str`). `name` - Override name (`str`) or `None` to exclude the reframe's name. Returns: This RefFrame's attributes (`str`). Overrides: named._Named.toStr

### Xform (self, reframe2) |
Get the converter Xform from this reference frame to `reframe2`. Arguments: `reframe2` - Destination frame to convert to (RefFrame or `str`). Returns: The TRFXform instance or `None` if not available. Raises: `TypeError` - Invalid `reframe2`.

### Xforms (self, inverse=False) |
Return all Xforms converting from or to this reference frame or both. Arguments: `inverse` - If `True`, get all from otherwise to Xforms un-inverted (`bool`) or if `inverse=2` (`int`) get all to Xforms inverted plus all froms. Returns: An ADict of `name=`TRFXforms from this reframe or if `inverse=True` to this reframe or both if `inverse=2`.

Property Details

### datum Get this reference frame's datum (Datum). Get method: datum(self) - Get this reference frame's datum (Datum). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### ellipsoid Get this reference frame's ellipsoid (Ellipsoid or Ellipsoid2). Get method: ellipsoid(self) - Get this reference frame's ellipsoid (Ellipsoid or Ellipsoid2). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### epoch Get this reference frame's epoch (`Epoch`). Get method: epoch(self) - Get this reference frame's epoch (`Epoch`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.